import Footer from "@/components/global/Footer";
import Header from "@/components/global/Header";
import { ThemeProvider } from "@/components/global/ThemeProvider";
import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";
import "./globals.css";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "Gaertan Art Admin",
  description: "Admin page for the gaertan.art website",
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en" suppressHydrationWarning>
      <body
        className={`${geistSans.variable} ${geistMono.variable} antialiased`}
      >
        <ThemeProvider
          attribute="class"
          defaultTheme="dark-violet"
          themes={[
            'light-zinc',
            'light-red',
            'light-rose',
            'light-orange',
            'light-green',
            'light-blue',
            'light-yellow',
            'light-violet',
            'dark-zinc',
            'dark-red',
            'dark-rose',
            'dark-orange',
            'dark-green',
            'dark-blue',
            'dark-yellow',
            'dark-violet',
          ]}
          enableSystem
          disableTransitionOnChange
        >
          <div className="flex flex-col min-h-screen min-w-screen">
            <header className="sticky top-0 z-50 h-14 w-full border-b bg-background/95 backdrop-blur supports-[backdrop-filter]:bg-background/60 px-4 py-2">
              <Header />
            </header>
            <main className="container mx-auto px-4 py-8">
              {children}
            </main>
            <footer className="mt-auto px-4 py-2 h-14 border-t bg-background/95 backdrop-blur supports-[backdrop-filter]:bg-background/60">
              <Footer />
            </footer>
          </div>
        </ThemeProvider>
      </body>
    </html>
  );
}
