"use client"

import { mockCards } from "@/data/mockCards"
import type { KanbanCardData } from "@/types/kanban"
import { DndContext, DragEndEvent, closestCenter } from "@dnd-kit/core"
import { useState } from "react"
import { KanbanColumn } from "./KanbanColumn"

export type Status = "PENDING" | "ACCEPTED" | "IN_PROGRESS" | "DONE" | "REJECTED"

const columns: Status[] = ["PENDING", "ACCEPTED", "IN_PROGRESS", "DONE", "REJECTED"]

export function KanbanBoard() {
  const [cards, setCards] = useState<Record<Status, KanbanCardData[]>>(mockCards)

  function findColumnByCardId(cardId: string): Status | null {
    for (const status of columns) {
      if (cards[status].some((c) => c.id === cardId)) return status
    }
    return null
  }

  function handleDragEnd(event: DragEndEvent) {
    const { active, over } = event
    if (!active || !over || active.id === over.id) return

    const from = findColumnByCardId(active.id as string)
    const to = over.id as Status
    if (!from || !to || from === to) return

    const card = cards[from].find((c) => c.id === active.id)
    if (!card) return

    setCards((prev) => {
      return {
        ...prev,
        [from]: prev[from].filter((c) => c.id !== card.id),
        [to]: [card, ...prev[to]],
      }
    })
  }

  return (
    <DndContext collisionDetection={closestCenter} onDragEnd={handleDragEnd}>
      <div className="grid grid-cols-1 md:grid-cols-2 xl:grid-cols-5 gap-4">
        {columns.map((status) => (
          <KanbanColumn key={status} status={status} items={cards[status]} />
        ))}
      </div>
    </DndContext>
  )
}
