"use client"

import type { KanbanCardData } from "@/types/kanban"
import { useDraggable } from "@dnd-kit/core"

interface KanbanCardPreviewProps extends KanbanCardData {
  onClick: () => void
}

export function KanbanCardPreview({
  id,
  title,
  labels = [],
  todos = [],
  onClick,
}: KanbanCardPreviewProps) {
  const { setNodeRef, attributes, listeners, transform, isDragging } = useDraggable({
    id,
  })

  const done = todos.filter((t) => t.done).length
  const total = todos.length

  return (
    <div
      ref={setNodeRef}
      {...listeners}
      {...attributes}
      onClick={onClick}
      className={`rounded-md bg-white dark:bg-zinc-900 border border-border p-3 shadow-sm cursor-pointer hover:ring-2 hover:ring-primary/40 transition ${isDragging ? "opacity-50" : ""
        }`}
      style={{
        transform: transform
          ? `translate(${transform.x}px, ${transform.y}px)`
          : undefined,
      }}
    >
      <div className="flex gap-1 mb-2 flex-wrap">
        {labels.map((label) => (
          <span
            key={label.id}
            className="w-3 h-3 rounded-full"
            style={{ backgroundColor: label.color }}
            title={label.name}
          />
        ))}
      </div>

      <div className="font-medium text-sm mb-1">{title}</div>

      {total > 0 && (
        <div className="text-xs text-muted-foreground">
          {done} / {total} tasks done
        </div>
      )}
    </div>
  )
}
