"use client"

import type { KanbanCardData } from "@/types/kanban"
import { useDroppable } from "@dnd-kit/core"
import { useState } from "react"
import type { Status } from "./KanbanBoard"
import { KanbanCardModal } from "./KanbanCardModal"
import { KanbanCardPreview } from "./KanbanCardPreview"

interface KanbanColumnProps {
  status: Status
  items: KanbanCardData[]
}

export function KanbanColumn({ status, items }: KanbanColumnProps) {
  const { setNodeRef } = useDroppable({ id: status })
  const [activeCard, setActiveCard] = useState<KanbanCardData | null>(null)

  return (
    <div
      ref={setNodeRef}
      className="bg-muted rounded-lg p-2 flex flex-col gap-2 min-h-[200px]"
    >
      <h2 className="text-lg font-semibold text-center mb-2">
        {status.replace("_", " ")}
      </h2>
      {items.map((item) => (
        <KanbanCardPreview
          key={item.id}
          {...item}
          onClick={() => setActiveCard(item)}
        />
      ))}

      <KanbanCardModal card={activeCard} onClose={() => setActiveCard(null)} />
    </div>
  )
}
